@@ -215,14 +215,13 @@ sub remove_if_empty {
 
 sub cleanup_group_state {
     my ($state, $group_id, $backlog) = @_;
-    my ($members, $member);
-    my $changed = 0;
+    my ($members);
     my $group_data = $state->{'groups'}{$group_id};
     $members = $group_data->{'members'};
     if (not exists($ACTIVE_GROUPS{$group_id}) or not $members) {
         # No members left, remove the group entirely
         delete($state->{'groups'}{$group_id});
-        if (exists($ACTIVE_GROUPS{$group_id})) {
+        if (not exists($ACTIVE_GROUPS{$group_id})) {
             log_debug("Group ${group_id} dropped: It is not an active group");
         } else {
             log_debug("Group ${group_id} dropped: No members left (early)");
@@ -434,11 +433,13 @@ sub prune_lintian_lab {
 sub _open_data_file {
     my ($file) = @_;
     if (-e $file) {
-        open(my $fd, '<', $file);
+        open(my $fd, '<:encoding(UTF-8)', $file);
         return $fd;
     }
     if (-e "${file}.gz") {
-        return open_gz("${file}.gz");
+        my $fd = open_gz("${file}.gz");
+        binmode($fd, 'encoding(UTF-8)');
+        return $fd;
     }
     die("Cannot find ${file}: file does not exist");
 }
